package javax.swing.plaf.nimbus;

import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Component;
import java.awt.RenderingHints;
import java.awt.image.BufferedImage;
import java.awt.Color;
import java.awt.Graphics2D;
import javax.swing.JComponent;
import java.awt.Insets;
import javax.swing.border.Border;

class LoweredBorder extends AbstractRegionPainter implements Border
{
    private static final int IMG_SIZE = 30;
    private static final int RADIUS = 13;
    private static final Insets INSETS;
    private static final AbstractRegionPainter.PaintContext PAINT_CONTEXT;
    
    LoweredBorder() {
    }
    
    @Override
    protected Object[] getExtendedCacheKeys(JComponent component) {
        return (component != null) ? new Object[] { component.getBackground() } : null;
    }
    
    @Override
    protected void doPaint(Graphics2D graphics2D, JComponent component, int n, int n2, Object[] array) {
        Color color = (component == null) ? Color.BLACK : component.getBackground();
        BufferedImage bufferedImage = new BufferedImage(30, 30, 2);
        BufferedImage bufferedImage2 = new BufferedImage(30, 30, 2);
        Graphics2D graphics2D2 = (Graphics2D)bufferedImage.getGraphics();
        graphics2D2.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
        graphics2D2.setColor(color);
        graphics2D2.fillRoundRect(2, 0, 26, 26, 13, 13);
        graphics2D2.dispose();
        InnerShadowEffect innerShadowEffect = new InnerShadowEffect();
        innerShadowEffect.setDistance(1);
        innerShadowEffect.setSize(3);
        innerShadowEffect.setColor(this.getLighter(color, 2.1f));
        innerShadowEffect.setAngle(90);
        innerShadowEffect.applyEffect(bufferedImage, bufferedImage2, 30, 30);
        Graphics2D graphics2D3 = (Graphics2D)bufferedImage2.getGraphics();
        graphics2D3.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
        graphics2D3.setClip(0, 28, 30, 1);
        graphics2D3.setColor(this.getLighter(color, 0.9f));
        graphics2D3.drawRoundRect(2, 1, 25, 25, 13, 13);
        graphics2D3.dispose();
        if (n != 30 || n2 != 30) {
            ImageScalingHelper.paint(graphics2D, 0, 0, n, n2, bufferedImage2, LoweredBorder.INSETS, LoweredBorder.INSETS, ImageScalingHelper.PaintType.PAINT9_STRETCH, 512);
        }
        else {
            graphics2D.drawImage(bufferedImage2, 0, 0, component);
        }
    }
    
    @Override
    protected AbstractRegionPainter.PaintContext getPaintContext() {
        return LoweredBorder.PAINT_CONTEXT;
    }
    
    @Override
    public Insets getBorderInsets(Component component) {
        return (Insets)LoweredBorder.INSETS.clone();
    }
    
    @Override
    public boolean isBorderOpaque() {
        return false;
    }
    
    @Override
    public void paintBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
        JComponent component2 = (component instanceof JComponent) ? ((JComponent)component) : null;
        if ((graphics instanceof Graphics2D)) {
            Graphics2D graphics2D2 = (Graphics2D)graphics;
            graphics2D2.translate(n, n2);
            this.paint(graphics2D2, component2, n3, n4);
            graphics2D2.translate(-n, -n2);
        }
        else {
            BufferedImage o = new BufferedImage(30, 30, 2);
            Graphics2D graphics2D = (Graphics2D)o.getGraphics();
            this.paint(graphics2D, component2, n3, n4);
            graphics2D.dispose();
            ImageScalingHelper.paint(graphics, n, n2, n3, n4, o, LoweredBorder.INSETS, LoweredBorder.INSETS, ImageScalingHelper.PaintType.PAINT9_STRETCH, 512);
        }
    }
    
    private Color getLighter(Color color, float n) {
        return new Color(Math.min((int)((float)color.getRed() / n), 255), Math.min((int)((float)color.getGreen() / n), 255), Math.min((int)((float)color.getBlue() / n), 255));
    }
    
    static {
        INSETS = new Insets(10, 10, 10, 10);
        PAINT_CONTEXT = new AbstractRegionPainter.PaintContext(LoweredBorder.INSETS, new Dimension(30, 30), false, AbstractRegionPainter.PaintContext.CacheMode.NINE_SQUARE_SCALE, 2.147483647E9, 2.147483647E9);
    }
}
